pub struct CharacterSettings {
pub auto_sell_enabled: bool,
pub dont_show_case_upgrade_popup_today: bool,
pub gear_override_enabled_item_types: Vec<ItemType>,
}Fields
auto_sell_enabled: booldont_show_case_upgrade_popup_today: boolgear_override_enabled_item_types: Vec<ItemType>Trait Implementations
Sourceimpl Clone for CharacterSettings
impl Clone for CharacterSettings
Sourcefn clone(&self) -> CharacterSettings
fn clone(&self) -> CharacterSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for CharacterSettings
impl CustomType for CharacterSettings
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for CharacterSettings
impl Debug for CharacterSettings
Sourceimpl Default for CharacterSettings
impl Default for CharacterSettings
Sourcefn default() -> CharacterSettings
fn default() -> CharacterSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CharacterSettings
impl<'de> Deserialize<'de> for CharacterSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CharacterSettings
impl JsonSchema for CharacterSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CharacterSettings
impl PartialEq for CharacterSettings
Sourceimpl Serialize for CharacterSettings
impl Serialize for CharacterSettings
Sourceimpl Tsify for CharacterSettings
impl Tsify for CharacterSettings
const DECL: &'static str = "export interface CharacterSettings {\n auto_sell_enabled: boolean;\n dont_show_case_upgrade_popup_today: boolean;\n gear_override_enabled_item_types: ItemType[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for CharacterSettings
impl StructuralPartialEq for CharacterSettings